@@ -261,14 +261,15 @@ head(as.data.frame(puechabonsp$map))
 
 
 ###################################################
-### code chunk number 35: adehabitatHR.Rnw:435-437
+### code chunk number 35: adehabitatHR.Rnw:435-438
 ###################################################
-enc <- over(puechabonsp$map, cp[,2], fn=function(x) return(1))
+enc <- over(puechabonsp$map, as(cp[2,],"SpatialPolygons"), fn=function(x) return(1))
+enc <- as.data.frame(enc)
 head(enc)
 
 
 ###################################################
-### code chunk number 36: adehabitatHR.Rnw:446-448
+### code chunk number 36: adehabitatHR.Rnw:447-449
 ###################################################
 coordinates(enc) <- coordinates(puechabonsp$map)
 gridded(enc) <- TRUE
@@ -282,14 +283,14 @@ gridded(enc) <- TRUE
 
 
 ###################################################
-### code chunk number 38: adehabitatHR.Rnw:458-459 (eval = FALSE)
+### code chunk number 38: adehabitatHR.Rnw:459-460 (eval = FALSE)
 ###################################################
 ## image(puechabonsp$map)
 ## image(enc, add=TRUE, col="black", useRasterImage=FALSE)
 
 
 ###################################################
-### code chunk number 39: adehabitatHR.Rnw:463-466
+### code chunk number 39: adehabitatHR.Rnw:464-467
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -301,7 +302,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 40: adehabitatHR.Rnw:474-475
+### code chunk number 40: adehabitatHR.Rnw:475-476
 ###################################################
 cprast <- hr.rast(cp, puechabonsp$map)
 
@@ -318,7 +319,7 @@ cprast <- hr.rast(cp, puechabonsp$map)
 
 
 ###################################################
-### code chunk number 42: adehabitatHR.Rnw:490-491 (eval = FALSE)
+### code chunk number 42: adehabitatHR.Rnw:491-492 (eval = FALSE)
 ###################################################
 ## par(mar=c(0,0,0,0))
 ## par(mfrow=c(2,2))
@@ -329,7 +330,7 @@ cprast <- hr.rast(cp, puechabonsp$map)
 
 
 ###################################################
-### code chunk number 43: adehabitatHR.Rnw:495-498
+### code chunk number 43: adehabitatHR.Rnw:496-499
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -345,7 +346,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 44: adehabitatHR.Rnw:509-510
+### code chunk number 44: adehabitatHR.Rnw:510-511
 ###################################################
 as.data.frame(cp)
 
@@ -357,13 +358,13 @@ as.data.frame(cp)
 
 
 ###################################################
-### code chunk number 46: adehabitatHR.Rnw:531-532 (eval = FALSE)
+### code chunk number 46: adehabitatHR.Rnw:532-533 (eval = FALSE)
 ###################################################
 ## hrs <- mcp.area(puechabonsp$relocs[,1], percent=seq(50, 100, by = 5))
 
 
 ###################################################
-### code chunk number 47: adehabitatHR.Rnw:536-539
+### code chunk number 47: adehabitatHR.Rnw:537-540
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -374,7 +375,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 48: adehabitatHR.Rnw:556-557
+### code chunk number 48: adehabitatHR.Rnw:557-558
 ###################################################
 hrs
 
@@ -397,7 +398,7 @@ hrs
 
 
 ###################################################
-### code chunk number 50: adehabitatHR.Rnw:607-613
+### code chunk number 50: adehabitatHR.Rnw:608-614
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -437,7 +438,7 @@ cat("\\includegraphics[height=7cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 52: adehabitatHR.Rnw:698-701
+### code chunk number 52: adehabitatHR.Rnw:699-702
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -460,7 +461,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 53: adehabitatHR.Rnw:768-771
+### code chunk number 53: adehabitatHR.Rnw:769-772
 ###################################################
 data(puechabonsp)
 kud <- kernelUD(puechabonsp$relocs[,1], h="href")
@@ -474,13 +475,13 @@ kud
 
 
 ###################################################
-### code chunk number 55: adehabitatHR.Rnw:783-784 (eval = FALSE)
+### code chunk number 55: adehabitatHR.Rnw:784-785 (eval = FALSE)
 ###################################################
 ## image(kud)
 
 
 ###################################################
-### code chunk number 56: adehabitatHR.Rnw:789-792
+### code chunk number 56: adehabitatHR.Rnw:790-793
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -491,7 +492,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 57: adehabitatHR.Rnw:800-801
+### code chunk number 57: adehabitatHR.Rnw:801-802
 ###################################################
 kud[[1]]@h
 
@@ -504,14 +505,14 @@ kud[[1]]@h
 
 
 ###################################################
-### code chunk number 59: adehabitatHR.Rnw:821-822 (eval = FALSE)
+### code chunk number 59: adehabitatHR.Rnw:822-823 (eval = FALSE)
 ###################################################
 ## kudl <- kernelUD(puechabonsp$relocs[,1], h="LSCV")
 ## image(kudl)
 
 
 ###################################################
-### code chunk number 60: adehabitatHR.Rnw:827-830
+### code chunk number 60: adehabitatHR.Rnw:828-831
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -529,13 +530,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 62: adehabitatHR.Rnw:847-848 (eval = FALSE)
+### code chunk number 62: adehabitatHR.Rnw:848-849 (eval = FALSE)
 ###################################################
 ## plotLSCV(kudl)
 
 
 ###################################################
-### code chunk number 63: adehabitatHR.Rnw:853-856
+### code chunk number 63: adehabitatHR.Rnw:854-857
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -574,7 +575,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 65: adehabitatHR.Rnw:946-947 (eval = FALSE)
+### code chunk number 65: adehabitatHR.Rnw:947-948 (eval = FALSE)
 ###################################################
 ## ## The relocations of "Brock"
 ## locs <- puechabonsp$relocs
@@ -602,7 +603,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 66: adehabitatHR.Rnw:951-954
+### code chunk number 66: adehabitatHR.Rnw:952-955
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -642,14 +643,14 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 68: adehabitatHR.Rnw:968-969 (eval = FALSE)
+### code chunk number 68: adehabitatHR.Rnw:969-970 (eval = FALSE)
 ###################################################
 ## kus <- kernelUD(puechabonsp$relocs[,1], same4all=TRUE)
 ## image(kus)
 
 
 ###################################################
-### code chunk number 69: adehabitatHR.Rnw:973-976
+### code chunk number 69: adehabitatHR.Rnw:974-977
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -661,20 +662,20 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 70: adehabitatHR.Rnw:983-985
+### code chunk number 70: adehabitatHR.Rnw:984-986
 ###################################################
 ii <- estUDm2spixdf(kus)
 class(ii)
 
 
 ###################################################
-### code chunk number 71: adehabitatHR.Rnw:1005-1006
+### code chunk number 71: adehabitatHR.Rnw:1006-1007
 ###################################################
 kudm <- kernelUD(puechabonsp$relocs[,1], grid=puechabonsp$map)
 
 
 ###################################################
-### code chunk number 72: adehabitatHR.Rnw:1033-1035
+### code chunk number 72: adehabitatHR.Rnw:1034-1036
 ###################################################
 homerange <- getverticeshr(kudl)
 class(homerange)
@@ -687,13 +688,13 @@ class(homerange)
 
 
 ###################################################
-### code chunk number 74: adehabitatHR.Rnw:1050-1051 (eval = FALSE)
+### code chunk number 74: adehabitatHR.Rnw:1051-1052 (eval = FALSE)
 ###################################################
 ## plot(homerange, col=1:4)
 
 
 ###################################################
-### code chunk number 75: adehabitatHR.Rnw:1055-1058
+### code chunk number 75: adehabitatHR.Rnw:1056-1059
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -704,7 +705,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 76: adehabitatHR.Rnw:1075-1077
+### code chunk number 76: adehabitatHR.Rnw:1076-1078
 ###################################################
 vud <- getvolumeUD(kudl)
 vud
@@ -737,7 +738,7 @@ vud
 
 
 ###################################################
-### code chunk number 78: adehabitatHR.Rnw:1108-1109 (eval = FALSE)
+### code chunk number 78: adehabitatHR.Rnw:1109-1110 (eval = FALSE)
 ###################################################
 ## 
 ## ## Set up graphical parameters
@@ -763,7 +764,7 @@ vud
 
 
 ###################################################
-### code chunk number 79: adehabitatHR.Rnw:1113-1116
+### code chunk number 79: adehabitatHR.Rnw:1114-1117
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -819,7 +820,7 @@ cat("\\includegraphics[height=14cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 81: adehabitatHR.Rnw:1150-1151 (eval = FALSE)
+### code chunk number 81: adehabitatHR.Rnw:1151-1152 (eval = FALSE)
 ###################################################
 ## ## store the volume under the UD (as computed by getvolumeUD)
 ## ## of the first animal in fud
@@ -844,7 +845,7 @@ cat("\\includegraphics[height=14cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 82: adehabitatHR.Rnw:1155-1158
+### code chunk number 82: adehabitatHR.Rnw:1156-1159
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -874,13 +875,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 83: adehabitatHR.Rnw:1171-1172
+### code chunk number 83: adehabitatHR.Rnw:1172-1173
 ###################################################
 as.data.frame(homerange)
 
 
 ###################################################
-### code chunk number 84: adehabitatHR.Rnw:1184-1186
+### code chunk number 84: adehabitatHR.Rnw:1185-1187
 ###################################################
 ii <- kernel.area(kudl, percent=seq(50, 95, by=5))
 ii
@@ -927,7 +928,7 @@ ii
 
 
 ###################################################
-### code chunk number 86: adehabitatHR.Rnw:1249-1252
+### code chunk number 86: adehabitatHR.Rnw:1250-1253
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -978,13 +979,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 88: adehabitatHR.Rnw:1295-1296 (eval = FALSE)
+### code chunk number 88: adehabitatHR.Rnw:1296-1297 (eval = FALSE)
 ###################################################
 ## image(puechabonsp$map)
 
 
 ###################################################
-### code chunk number 89: adehabitatHR.Rnw:1300-1303
+### code chunk number 89: adehabitatHR.Rnw:1301-1304
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1014,7 +1015,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 91: adehabitatHR.Rnw:1332-1333 (eval = FALSE)
+### code chunk number 91: adehabitatHR.Rnw:1333-1334 (eval = FALSE)
 ###################################################
 ## bound <- structure(list(x = c(701751.385381925, 701019.24105475,
 ##                         700739.303517889,
@@ -1033,7 +1034,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 92: adehabitatHR.Rnw:1337-1340
+### code chunk number 92: adehabitatHR.Rnw:1338-1341
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1057,7 +1058,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 93: adehabitatHR.Rnw:1347-1352
+### code chunk number 93: adehabitatHR.Rnw:1348-1353
 ###################################################
 ## We convert bound to SpatialLines:
 bound <- do.call("cbind",bound)
@@ -1074,14 +1075,14 @@ barrier <- SpatialLines(list(Sli1))
 
 
 ###################################################
-### code chunk number 95: adehabitatHR.Rnw:1363-1364 (eval = FALSE)
+### code chunk number 95: adehabitatHR.Rnw:1364-1365 (eval = FALSE)
 ###################################################
 ## kud <- kernelUD(puechabonsp$relocs[,1], h=100, grid=100, boundary=barrier)
 ## image(kud)
 
 
 ###################################################
-### code chunk number 96: adehabitatHR.Rnw:1368-1371
+### code chunk number 96: adehabitatHR.Rnw:1369-1372
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1111,7 +1112,7 @@ cat("\\includegraphics[height=14cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 98: adehabitatHR.Rnw:1412-1415
+### code chunk number 98: adehabitatHR.Rnw:1413-1416
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1134,7 +1135,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 99: adehabitatHR.Rnw:1425-1426
+### code chunk number 99: adehabitatHR.Rnw:1426-1427
 ###################################################
 pt <- 16
 
@@ -1192,7 +1193,7 @@ pt <- 16
 
 
 ###################################################
-### code chunk number 101: adehabitatHR.Rnw:1481-1484
+### code chunk number 101: adehabitatHR.Rnw:1482-1485
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1249,13 +1250,13 @@ cat("\\includegraphics[height=14cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 102: adehabitatHR.Rnw:1488-1489
+### code chunk number 102: adehabitatHR.Rnw:1489-1490
 ###################################################
 pt <- 25
 
 
 ###################################################
-### code chunk number 103: adehabitatHR.Rnw:1531-1533
+### code chunk number 103: adehabitatHR.Rnw:1532-1534
 ###################################################
 wi <- 800
 pt <- 18
@@ -1295,7 +1296,7 @@ pt <- 18
 
 
 ###################################################
-### code chunk number 105: adehabitatHR.Rnw:1569-1572
+### code chunk number 105: adehabitatHR.Rnw:1570-1573
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1333,14 +1334,14 @@ cat("\\includegraphics[height=14cm,width=14cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 106: adehabitatHR.Rnw:1577-1579
+### code chunk number 106: adehabitatHR.Rnw:1578-1580
 ###################################################
 wi <- 600
 pt <- 25
 
 
 ###################################################
-### code chunk number 107: adehabitatHR.Rnw:1596-1599
+### code chunk number 107: adehabitatHR.Rnw:1597-1600
 ###################################################
 data(puechcirc)
 x <- puechcirc[1]
@@ -1354,13 +1355,13 @@ x
 
 
 ###################################################
-### code chunk number 109: adehabitatHR.Rnw:1608-1609 (eval = FALSE)
+### code chunk number 109: adehabitatHR.Rnw:1609-1610 (eval = FALSE)
 ###################################################
 ## plot(x)
 
 
 ###################################################
-### code chunk number 110: adehabitatHR.Rnw:1613-1616
+### code chunk number 110: adehabitatHR.Rnw:1614-1617
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1377,13 +1378,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 112: adehabitatHR.Rnw:1633-1634 (eval = FALSE)
+### code chunk number 112: adehabitatHR.Rnw:1634-1635 (eval = FALSE)
 ###################################################
 ## lik <- liker(x, sig2 = 58, rangesig1 = c(10, 100))
 
 
 ###################################################
-### code chunk number 113: adehabitatHR.Rnw:1638-1641
+### code chunk number 113: adehabitatHR.Rnw:1639-1642
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1400,13 +1401,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 115: adehabitatHR.Rnw:1652-1653 (eval = FALSE)
+### code chunk number 115: adehabitatHR.Rnw:1653-1654 (eval = FALSE)
 ###################################################
 ## lik2 <- liker(x, sig2 = 58, rangesig1 = c(1, 10))
 
 
 ###################################################
-### code chunk number 116: adehabitatHR.Rnw:1657-1660
+### code chunk number 116: adehabitatHR.Rnw:1658-1661
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1417,13 +1418,13 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 117: adehabitatHR.Rnw:1666-1667
+### code chunk number 117: adehabitatHR.Rnw:1667-1668
 ###################################################
 lik2
 
 
 ###################################################
-### code chunk number 118: adehabitatHR.Rnw:1673-1675
+### code chunk number 118: adehabitatHR.Rnw:1674-1676
 ###################################################
 tata <- kernelbb(x, sig1 = 6.23, sig2 = 58, grid = 50)
 tata
@@ -1437,14 +1438,14 @@ tata
 
 
 ###################################################
-### code chunk number 120: adehabitatHR.Rnw:1687-1688 (eval = FALSE)
+### code chunk number 120: adehabitatHR.Rnw:1688-1689 (eval = FALSE)
 ###################################################
 ## image(tata)
 ## plot(getverticeshr(tata, 95), add=TRUE, lwd=2)
 
 
 ###################################################
-### code chunk number 121: adehabitatHR.Rnw:1692-1695
+### code chunk number 121: adehabitatHR.Rnw:1693-1696
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1468,7 +1469,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 123: adehabitatHR.Rnw:1722-1725
+### code chunk number 123: adehabitatHR.Rnw:1723-1726
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1522,7 +1523,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 125: adehabitatHR.Rnw:1820-1823
+### code chunk number 125: adehabitatHR.Rnw:1821-1824
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1564,7 +1565,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 126: adehabitatHR.Rnw:1889-1892
+### code chunk number 126: adehabitatHR.Rnw:1890-1893
 ###################################################
 data(buffalo)
 tr <- buffalo$traj
@@ -1578,13 +1579,13 @@ tr
 
 
 ###################################################
-### code chunk number 128: adehabitatHR.Rnw:1903-1904 (eval = FALSE)
+### code chunk number 128: adehabitatHR.Rnw:1904-1905 (eval = FALSE)
 ###################################################
 ## plot(tr, spixdf=buffalo$habitat)
 
 
 ###################################################
-### code chunk number 129: adehabitatHR.Rnw:1908-1911
+### code chunk number 129: adehabitatHR.Rnw:1909-1912
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1595,14 +1596,14 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 130: adehabitatHR.Rnw:1925-1927
+### code chunk number 130: adehabitatHR.Rnw:1926-1928
 ###################################################
 vv <- BRB.D(tr, Tmax=180*60, Lmin=50, habitat=buffalo$habitat, activity="act")
 vv
 
 
 ###################################################
-### code chunk number 131: adehabitatHR.Rnw:1942-1946
+### code chunk number 131: adehabitatHR.Rnw:1943-1947
 ###################################################
 ud <- BRB(tr, D = vv, Tmax = 180*60, tau = 300, Lmin = 50, hmin=100,
           habitat = buffalo$habitat, activity = "act", grid = 100, b=0,
@@ -1617,13 +1618,13 @@ ud
 
 
 ###################################################
-### code chunk number 133: adehabitatHR.Rnw:1960-1961 (eval = FALSE)
+### code chunk number 133: adehabitatHR.Rnw:1961-1962 (eval = FALSE)
 ###################################################
 ## image(ud)
 
 
 ###################################################
-### code chunk number 134: adehabitatHR.Rnw:1965-1968
+### code chunk number 134: adehabitatHR.Rnw:1966-1969
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1668,7 +1669,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 136: adehabitatHR.Rnw:2068-2069 (eval = FALSE)
+### code chunk number 136: adehabitatHR.Rnw:2069-2070 (eval = FALSE)
 ###################################################
 ## id <- BRB(buffalo$traj, D = 7.36, Tmax = 3*3600, Lmin = 50, type = "ID",
 ##           hmin=100, radius = 300, maxt = 2*3600, tau = 300,
@@ -1702,7 +1703,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 137: adehabitatHR.Rnw:2073-2076
+### code chunk number 137: adehabitatHR.Rnw:2074-2077
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1741,14 +1742,14 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 138: adehabitatHR.Rnw:2154-2156
+### code chunk number 138: adehabitatHR.Rnw:2155-2157
 ###################################################
 data(bear)
 bear
 
 
 ###################################################
-### code chunk number 139: adehabitatHR.Rnw:2165-2168
+### code chunk number 139: adehabitatHR.Rnw:2166-2169
 ###################################################
 uu <- kernelkc(bear, h = c(1000,1000,72*3600),
                tcalc= as.POSIXct("2004-05-01"), grid=50)
@@ -1762,13 +1763,13 @@ uu
 
 
 ###################################################
-### code chunk number 141: adehabitatHR.Rnw:2179-2180 (eval = FALSE)
+### code chunk number 141: adehabitatHR.Rnw:2180-2181 (eval = FALSE)
 ###################################################
 ## plot(bear, spixdf=uu)
 
 
 ###################################################
-### code chunk number 142: adehabitatHR.Rnw:2184-2187
+### code chunk number 142: adehabitatHR.Rnw:2185-2188
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1779,7 +1780,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 143: adehabitatHR.Rnw:2195-2196
+### code chunk number 143: adehabitatHR.Rnw:2196-2197
 ###################################################
 sum(slot(uu,"data")[,1])*(gridparameters(uu)[1,2]^2)
 
@@ -1793,7 +1794,7 @@ sum(slot(uu,"data")[,1])*(gridparameters(uu)[1,2]^2)
 
 
 ###################################################
-### code chunk number 145: adehabitatHR.Rnw:2220-2221 (eval = FALSE)
+### code chunk number 145: adehabitatHR.Rnw:2221-2222 (eval = FALSE)
 ###################################################
 ## ver <- getverticeshr(uu, percent=95, standardize=TRUE)
 ## image(uu)
@@ -1801,7 +1802,7 @@ sum(slot(uu,"data")[,1])*(gridparameters(uu)[1,2]^2)
 
 
 ###################################################
-### code chunk number 146: adehabitatHR.Rnw:2225-2228
+### code chunk number 146: adehabitatHR.Rnw:2226-2229
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1814,7 +1815,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 147: adehabitatHR.Rnw:2240-2272 (eval = FALSE)
+### code chunk number 147: adehabitatHR.Rnw:2241-2273 (eval = FALSE)
 ###################################################
 ## ## compute the sequence of dates at which the UD is to be
 ## ## estimated
@@ -1851,7 +1852,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 148: adehabitatHR.Rnw:2296-2297
+### code chunk number 148: adehabitatHR.Rnw:2297-2298
 ###################################################
 t0 <- as.POSIXct("2012-12-25 00:00")
 
@@ -1863,13 +1864,13 @@ t0 <- as.POSIXct("2012-12-25 00:00")
 
 
 ###################################################
-### code chunk number 150: adehabitatHR.Rnw:2308-2309 (eval = FALSE)
+### code chunk number 150: adehabitatHR.Rnw:2309-2310 (eval = FALSE)
 ###################################################
 ## exwc(0.2)
 
 
 ###################################################
-### code chunk number 151: adehabitatHR.Rnw:2313-2316
+### code chunk number 151: adehabitatHR.Rnw:2314-2317
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1888,7 +1889,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 153: adehabitatHR.Rnw:2332-2333 (eval = FALSE)
+### code chunk number 153: adehabitatHR.Rnw:2333-2334 (eval = FALSE)
 ###################################################
 ## uu <- kernelkc(bear, h=c(1000,1000,0.2), cycle=24*3600,
 ##                tcalc=3*3600, t0=t0, circular=TRUE)
@@ -1896,7 +1897,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 154: adehabitatHR.Rnw:2337-2340
+### code chunk number 154: adehabitatHR.Rnw:2338-2341
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1909,7 +1910,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 155: adehabitatHR.Rnw:2402-2404
+### code chunk number 155: adehabitatHR.Rnw:2403-2405
 ###################################################
 uu <- clusthr(puechabonsp$relocs[,1])
 class(uu)
@@ -1922,13 +1923,13 @@ class(uu)
 
 
 ###################################################
-### code chunk number 157: adehabitatHR.Rnw:2417-2418 (eval = FALSE)
+### code chunk number 157: adehabitatHR.Rnw:2418-2419 (eval = FALSE)
 ###################################################
 ## plot(uu)
 
 
 ###################################################
-### code chunk number 158: adehabitatHR.Rnw:2422-2425
+### code chunk number 158: adehabitatHR.Rnw:2423-2426
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1939,7 +1940,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 159: adehabitatHR.Rnw:2432-2433
+### code chunk number 159: adehabitatHR.Rnw:2433-2434
 ###################################################
 as.data.frame(uu[[3]])
 
@@ -1951,13 +1952,13 @@ as.data.frame(uu[[3]])
 
 
 ###################################################
-### code chunk number 161: adehabitatHR.Rnw:2445-2446 (eval = FALSE)
+### code chunk number 161: adehabitatHR.Rnw:2446-2447 (eval = FALSE)
 ###################################################
 ## plot(uu[[3]][26,])
 
 
 ###################################################
-### code chunk number 162: adehabitatHR.Rnw:2450-2453
+### code chunk number 162: adehabitatHR.Rnw:2451-2454
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1975,14 +1976,14 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 164: adehabitatHR.Rnw:2470-2471 (eval = FALSE)
+### code chunk number 164: adehabitatHR.Rnw:2471-2472 (eval = FALSE)
 ###################################################
 ## uur <- MCHu.rast(uu, puechabonsp$map, percent=90)
 ## image(uur, 3)
 
 
 ###################################################
-### code chunk number 165: adehabitatHR.Rnw:2475-2478
+### code chunk number 165: adehabitatHR.Rnw:2476-2479
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -1994,7 +1995,7 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 166: adehabitatHR.Rnw:2489-2490
+### code chunk number 166: adehabitatHR.Rnw:2490-2491
 ###################################################
 head(as.data.frame(uu[[1]]))
 
@@ -2006,13 +2007,13 @@ head(as.data.frame(uu[[1]]))
 
 
 ###################################################
-### code chunk number 168: adehabitatHR.Rnw:2504-2505 (eval = FALSE)
+### code chunk number 168: adehabitatHR.Rnw:2505-2506 (eval = FALSE)
 ###################################################
 ## ii <- MCHu2hrsize(uu, percent=seq(50, 100, by=5))
 
 
 ###################################################
-### code chunk number 169: adehabitatHR.Rnw:2509-2512
+### code chunk number 169: adehabitatHR.Rnw:2510-2513
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
@@ -2023,26 +2024,26 @@ cat("\\includegraphics[height=7cm,width=7cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 170: adehabitatHR.Rnw:2571-2572 (eval = FALSE)
+### code chunk number 170: adehabitatHR.Rnw:2572-2573 (eval = FALSE)
 ###################################################
 ## res <- LoCoH.k(puechabonsp$relocs[,1], 10)
 
 
 ###################################################
-### code chunk number 171: adehabitatHR.Rnw:2582-2583 (eval = FALSE)
+### code chunk number 171: adehabitatHR.Rnw:2583-2584 (eval = FALSE)
 ###################################################
 ## plot(res)
 
 
 ###################################################
-### code chunk number 172: adehabitatHR.Rnw:2590-2592 (eval = FALSE)
+### code chunk number 172: adehabitatHR.Rnw:2591-2593 (eval = FALSE)
 ###################################################
 ## LoCoH.k.area(puechabonsp$relocs[,1], krange=seq(4, 15, length=5),
 ##              percent=100)
 
 
 ###################################################
-### code chunk number 173: adehabitatHR.Rnw:2614-2616
+### code chunk number 173: adehabitatHR.Rnw:2615-2617
 ###################################################
 res <- CharHull(puechabonsp$relocs[,1])
 class(res)
@@ -2055,13 +2056,13 @@ class(res)
 
 
 ###################################################
-### code chunk number 175: adehabitatHR.Rnw:2632-2633 (eval = FALSE)
+### code chunk number 175: adehabitatHR.Rnw:2633-2634 (eval = FALSE)
 ###################################################
 ## plot(res)
 
 
 ###################################################
-### code chunk number 176: adehabitatHR.Rnw:2637-2640
+### code chunk number 176: adehabitatHR.Rnw:2638-2641
 ###################################################
 .PngNo <- .PngNo + 1; file <- paste("Fig-bitmap-",
           .PngNo, ".png", sep="")
